==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/shell/tests/share/kde4/services/kdevnonguiinterfaceplugin.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin is purely for unit-test
Comment[bg]=Тази приставка е само за проверка на модула
Comment[bs]=Ovaj dodatak je isključivo za test jedinice
Comment[ca]=Aquest connector és exclusivament per a unitats de proves
Comment[ca@valencia]=Este connector és exclusivament per a unitats de proves
Comment[da]=Dette plugin er udelukkende til unit-test
Comment[de]=Dieses Modul dient nur Unit-Tests.
Comment[el]=Αυτό το πρόσθετο προορίζεται για τον έλεγχο μονάδας
Comment[en_GB]=This plugin is purely for unit-test
Comment[es]=Este complemento es solo para pruebas unitarias
Comment[et]=See plugin on ainult ühiktesti jaoks
Comment[fi]=Tämä liitännäinen on puhtaasti yksikkötestausta varten
Comment[fr]=Ce module externe est purement pour le test unitaire
Comment[gl]=Este complemento é soamente para probas unitarias
Comment[hu]=Ez a bővítmény tisztán az egységtesztekhez van
Comment[it]=Questa estensione è puramente per lo test d'unità
Comment[kk]=Тек модулін сынауға арналған плагині
Comment[nb]=Dette programtillegget er bare for enhetstesting
Comment[nds]=Dit Moduul is bloots för't Eenheiten-Testen
Comment[nl]=Deze plugin is alleen voor eenheid-testen
Comment[pa]=ਇਹ ਪਲੱਗਇਨ ਸ਼ੁੱਧ ਯੂਨਿਟ-ਟੈਸਟ ਹੈ
Comment[pl]=Ta wtyczka służy tylko do testów jednostek
Comment[pt]=Este 'plugin' serve apenas para testes unitários
Comment[pt_BR]=Esta extensão é somente para testes unitários
Comment[ru]=Это расширение предназначено исключительно для модульного тестирования
Comment[sk]=Tento plugin je čisto na unit testy
Comment[sl]=Ta vstavek je samo za preizkušanje enot
Comment[sv]=Insticksprogrammet är enbart avsett för enhetstest
Comment[tr]=Bu eklenti tamamen birim-testleri içindir
Comment[ug]=بۇ قىستۇرما پەقەتلا unit-test ئۈچۈن
Comment[uk]=Цей додаток призначено лише для перевірки модулів
Comment[x-test]=xxThis plugin is purely for unit-testxx
Comment[zh_CN]=此插件只用于 unit 测试
Comment[zh_TW]=此外掛程式只是單純做測試
Name=KDevNonGuiInterface
Name[bg]=KDevNonGuiInterface
Name[bs]=KDevNonGUI sučelje
Name[ca]=KDevNonGuiInterface
Name[ca@valencia]=KDevNonGuiInterface
Name[da]=KDevNonGuiInterface
Name[de]=KDevNonGuiInterface
Name[el]=KDevNonGuiInterface
Name[en_GB]=KDevNonGuiInterface
Name[es]=KDevNonGuiInterface
Name[et]=KDevNonGuiInterface
Name[fi]=KDevNonGuiInterface
Name[fr]=KDevNonGuiInterface
Name[ga]=KDevNonGuiInterface
Name[gl]=KDevNonGuiInterface
Name[hu]=KDevNonGuiInterface
Name[it]=KDevNonGuiInterface
Name[kk]=KDevNonGuiInterface
Name[nb]=KDevNonGuiInterface
Name[nds]=KDevKeenBöversiet
Name[nl]=KDevNonGuiInterface
Name[pa]=KDevNonGuiInterface
Name[pl]=KDevNonGuiInterface
Name[pt]=KDevNonGuiInterface
Name[pt_BR]=KDevNonGuiInterface
Name[ru]=KDevNonGuiInterface
Name[sk]=KDevNonGuiInterface
Name[sl]=KDevNonGuiInterface
Name[sv]=KDevelop icke grafiskt användargränssnitt
Name[tr]=KDevNonGuiInterface
Name[ug]=KDevNonGuiInterface
Name[uk]=KDevNonGuiInterface
Name[x-test]=xxKDevNonGuiInterfacexx
Name[zh_CN]=KDevNonGuiInterface
Name[zh_TW]=KDevNonGuiInterface
GenericName=NonGuiInterface
GenericName[bg]=NonGuiInterface
GenericName[bs]=NonGuiInterface
GenericName[ca]=NonGuiInterface
GenericName[ca@valencia]=NonGuiInterface
GenericName[da]=NonGuiInterface
GenericName[de]=NonGuiInterface
GenericName[el]=Περιβάλλον χωρίς Gui
GenericName[en_GB]=NonGuiInterface
GenericName[es]=NonGuiInterface
GenericName[et]=NonGuiInterface
GenericName[fi]=NonGuiInterface
GenericName[fr]=NonGuiInterface
GenericName[ga]=NonGuiInterface
GenericName[gl]=Interface sen gui
GenericName[hu]=NonGuiInterface
GenericName[it]=NonGuiInterface
GenericName[kk]=NonGuiInterface
GenericName[nb]=NonGuiInterface
GenericName[nds]=Keen graafsch Böversiet
GenericName[nl]=NonGuiInterface
GenericName[pa]=NonGuiInterface
GenericName[pl]=NonGuiInterface
GenericName[pt]=Interface Não-Gráfica
GenericName[pt_BR]=NonGuiInterface
GenericName[ru]=NonGuiInterface
GenericName[sk]=NonGuiInterface
GenericName[sl]=NonGuiInterface
GenericName[sv]=Icke grafiskt användargränssnitt
GenericName[tr]=Grafiksel Olmayan Arayüz
GenericName[ug]=NonGuiInterface
GenericName[uk]=NonGuiInterface
GenericName[x-test]=xxNonGuiInterfacexx
GenericName[zh_CN]=非图形用户界面
GenericName[zh_TW]=NonGuiInterface
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevnonguiinterfaceplugin
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevnonguiinterface
X-KDE-PluginInfo-License=LGPL
X-KDevelop-Interfaces=org.kdevelop.ITestNonGuiInterface
X-KDevelop-Mode=NoGUI

==> kdevplatform_1.7.0.orig.tar.xz: kdevplatform-1.7.0/shell/tests/share/kde4/services/kdevnonguiinterfaceplugin.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin is purely for unit-test
Comment[bg]=Тази приставка е само за проверка на модула
Comment[bs]=Ovaj dodatak je isključivo za test jedinice
Comment[ca]=Aquest connector és exclusivament per a unitats de proves
Comment[ca@valencia]=Este connector és exclusivament per a unitats de proves
Comment[da]=Dette plugin er udelukkende til unit-test
Comment[de]=Dieses Modul dient nur Unit-Tests.
Comment[el]=Αυτό το πρόσθετο προορίζεται για τον έλεγχο μονάδας
Comment[en_GB]=This plugin is purely for unit-test
Comment[es]=Este complemento es solo para pruebas unitarias
Comment[et]=See plugin on ainult ühiktesti jaoks
Comment[fi]=Tämä liitännäinen on puhtaasti yksikkötestausta varten
Comment[fr]=Ce module externe est purement pour le test unitaire
Comment[gl]=Este complemento é soamente para probas unitarias
Comment[hu]=Ez a bővítmény tisztán az egységtesztekhez van
Comment[it]=Questa estensione è puramente per lo test d'unità
Comment[kk]=Тек модулін сынауға арналған плагині
Comment[nb]=Dette programtillegget er bare for enhetstesting
Comment[nds]=Dit Moduul is bloots för't Eenheiten-Testen
Comment[nl]=Deze plugin is alleen voor eenheid-testen
Comment[pa]=ਇਹ ਪਲੱਗਇਨ ਸ਼ੁੱਧ ਯੂਨਿਟ-ਟੈਸਟ ਹੈ
Comment[pl]=Ta wtyczka służy tylko do testów jednostek
Comment[pt]=Este 'plugin' serve apenas para testes unitários
Comment[pt_BR]=Esta extensão é somente para testes unitários
Comment[ru]=Это расширение предназначено исключительно для модульного тестирования
Comment[sk]=Tento plugin je čisto na unit testy
Comment[sl]=Ta vstavek je samo za preizkušanje enot
Comment[sv]=Insticksprogrammet är enbart avsett för enhetstest
Comment[tr]=Bu eklenti tamamen birim-testleri içindir
Comment[ug]=بۇ قىستۇرما پەقەتلا unit-test ئۈچۈن
Comment[uk]=Цей додаток призначено лише для перевірки модулів
Comment[x-test]=xxThis plugin is purely for unit-testxx
Comment[zh_CN]=此插件只用于单元测试
Comment[zh_TW]=此外掛程式只是單純做測試
Name=KDevNonGuiInterface
Name[bg]=KDevNonGuiInterface
Name[bs]=KDevNonGUI sučelje
Name[ca]=KDevNonGuiInterface
Name[ca@valencia]=KDevNonGuiInterface
Name[da]=KDevNonGuiInterface
Name[de]=KDevNonGuiInterface
Name[el]=KDevNonGuiInterface
Name[en_GB]=KDevNonGuiInterface
Name[es]=KDevNonGuiInterface
Name[et]=KDevNonGuiInterface
Name[fi]=KDevNonGuiInterface
Name[fr]=KDevNonGuiInterface
Name[ga]=KDevNonGuiInterface
Name[gl]=KDevNonGuiInterface
Name[hu]=KDevNonGuiInterface
Name[it]=KDevNonGuiInterface
Name[kk]=KDevNonGuiInterface
Name[nb]=KDevNonGuiInterface
Name[nds]=KDevKeenBöversiet
Name[nl]=KDevNonGuiInterface
Name[pa]=KDevNonGuiInterface
Name[pl]=KDevNonGuiInterface
Name[pt]=KDevNonGuiInterface
Name[pt_BR]=KDevNonGuiInterface
Name[ru]=KDevNonGuiInterface
Name[sk]=KDevNonGuiInterface
Name[sl]=KDevNonGuiInterface
Name[sv]=KDevelop icke grafiskt användargränssnitt
Name[tr]=KDevNonGuiInterface
Name[ug]=KDevNonGuiInterface
Name[uk]=KDevNonGuiInterface
Name[x-test]=xxKDevNonGuiInterfacexx
Name[zh_CN]=KDevNonGuiInterface
Name[zh_TW]=KDevNonGuiInterface
GenericName=NonGuiInterface
GenericName[bg]=NonGuiInterface
GenericName[bs]=NonGuiInterface
GenericName[ca]=NonGuiInterface
GenericName[ca@valencia]=NonGuiInterface
GenericName[da]=NonGuiInterface
GenericName[de]=NonGuiInterface
GenericName[el]=Περιβάλλον χωρίς Gui
GenericName[en_GB]=NonGuiInterface
GenericName[es]=NonGuiInterface
GenericName[et]=NonGuiInterface
GenericName[fi]=NonGuiInterface
GenericName[fr]=NonGuiInterface
GenericName[ga]=NonGuiInterface
GenericName[gl]=Interface sen gui
GenericName[hu]=NonGuiInterface
GenericName[it]=NonGuiInterface
GenericName[kk]=NonGuiInterface
GenericName[nb]=NonGuiInterface
GenericName[nds]=Keen graafsch Böversiet
GenericName[nl]=NonGuiInterface
GenericName[pa]=NonGuiInterface
GenericName[pl]=NonGuiInterface
GenericName[pt]=Interface Não-Gráfica
GenericName[pt_BR]=NonGuiInterface
GenericName[ru]=NonGuiInterface
GenericName[sk]=NonGuiInterface
GenericName[sl]=NonGuiInterface
GenericName[sv]=Icke grafiskt användargränssnitt
GenericName[tr]=Grafiksel Olmayan Arayüz
GenericName[ug]=NonGuiInterface
GenericName[uk]=NonGuiInterface
GenericName[x-test]=xxNonGuiInterfacexx
GenericName[zh_CN]=NonGuiInterface
GenericName[zh_TW]=NonGuiInterface
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevnonguiinterfaceplugin
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevnonguiinterface
X-KDE-PluginInfo-License=LGPL
X-KDevelop-Interfaces=org.kdevelop.ITestNonGuiInterface
X-KDevelop-Mode=NoGUI
